@@ -6,7 +6,7 @@ use Text::Xslate;
 use namespace::autoclean;
 use Scalar::Util qw/blessed weaken/;
 
-our $VERSION = '0.00012';
+our $VERSION = '0.00013';
 
 extends 'Catalyst::View';
 
@@ -56,6 +56,20 @@ has function => (
     trigger => $clearer,
 );
 
+has footer => (
+    is => 'rw',
+    isa => 'ArrayRef',
+    default => sub { +[] },
+    trigger => $clearer
+);
+
+has header => (
+    is => 'rw',
+    isa => 'ArrayRef',
+    default => sub { +[] },
+    trigger => $clearer
+);
+
 has module => (
     is => 'rw',
     isa => 'ArrayRef',
@@ -80,6 +94,12 @@ has escape => (
     isa => 'Str',
     trigger => $clearer,
 );
+
+has suffix => (
+    is => 'rw',
+    isa => 'Str',
+    trigger => $clearer,
+);
     
 has verbose => (
     is => 'rw',
@@ -117,13 +137,12 @@ sub _build_xslate {
     my %args = (
         path      => $self->path || [ $c->path_to('root') ],
         cache_dir => $self->cache_dir || File::Spec->catdir(File::Spec->tmpdir, $name),
-        cache     => $self->cache,
-        function  => $self->function,
-        module    => $self->module,
+        map { ($_ => $self->$_) }
+            qw( cache footer function header module )
     );
 
     # optional stuff
-    foreach my $field ( qw( input_layer syntax escape verbose ) ) {
+    foreach my $field ( qw( input_layer syntax escape verbose suffix ) ) {
         if (my $value = $self->$field) {
             $args{$field} = $value;
         }
@@ -246,6 +265,11 @@ The name used to refer to the Catalyst app object in the template
 The suffix used to auto generate the template name from the action name
 (when you do not explicitly specify the template filename);
 
+Do not confuse this with the C<suffix> option, which is passed directly to
+the Text::Xslate object instance. This option works on the filename used
+for the initial request, while C<suffix> controls what C<cascade> and
+C<include> directives do inside Text::Xslate.
+
 =head2 content_charset
 
 The charset used to output the response body. The value defaults to 'UTF-8'.
@@ -262,10 +286,24 @@ cause the previously created underlying Text::Xslate object to be cleared
 
 =head2 cache
 
+=head2 header
+
+=head2 escape
+
+=head2 footer
+
 =head2 function
 
+=head2 input_layer
+
 =head2 module
 
+=head2 syntax
+
+=head2 verbose
+
+=head2 suffix
+
 Use this to enable TT2 compatible variable methods via Text::Xslate::Bridge::TT2 or Text::Xslate::Bridge::TT2Like
 
     package MyApp::View::Xslate;
